@@ -39,7 +39,6 @@ lda_c_wigner_init(xc_func_type *p)
   p->params = libxc_malloc(sizeof(lda_c_wigner_params));
 }
 
-#include "decl_lda.h"
 #include "maple2c/lda_exc/lda_c_wigner.c"
 #include "work_lda.c"
 
@@ -56,7 +55,7 @@ const xc_func_info_type xc_func_info_lda_c_wigner = {
   1e-24,
   {N_PAR, names, desc, val_wigner, set_ext_params_cpy},
   lda_c_wigner_init, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
 
 #ifdef __cplusplus
@@ -72,7 +71,7 @@ const xc_func_info_type xc_func_info_lda_xc_lp_a = {
   1e-24,
   {N_PAR, names, desc, val_lp_a, set_ext_params_cpy},
   lda_c_wigner_init, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
 
 #ifdef __cplusplus
@@ -88,7 +87,7 @@ const xc_func_info_type xc_func_info_lda_xc_lp_b = {
   1e-24,
   {N_PAR, names, desc, val_lp_b, set_ext_params_cpy},
   lda_c_wigner_init, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
 
 #ifdef __cplusplus
@@ -104,7 +103,7 @@ const xc_func_info_type xc_func_info_lda_c_mcweeny = {
   1e-24,
   {N_PAR, names, desc, val_mcweeny, set_ext_params_cpy},
   lda_c_wigner_init, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
 
 #ifdef __cplusplus
@@ -120,7 +119,7 @@ const xc_func_info_type xc_func_info_lda_c_br78 = {
   1e-24,
   {N_PAR, names, desc, val_br78, set_ext_params_cpy},
   lda_c_wigner_init, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
 
 #ifdef __cplusplus
@@ -136,7 +135,7 @@ const xc_func_info_type xc_func_info_lda_c_ow_lyp = {
   1e-24,
   {N_PAR, names, desc, val_ow_lyp, set_ext_params_cpy},
   lda_c_wigner_init, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
 
 #ifdef __cplusplus
@@ -152,6 +151,6 @@ const xc_func_info_type xc_func_info_lda_c_ow = {
   1e-24,
   {N_PAR, names, desc, val_ow, set_ext_params_cpy},
   lda_c_wigner_init, NULL,
-  work_lda, NULL, NULL
+  &work_lda, NULL, NULL
 };
 
