@@ -23,7 +23,6 @@ static const char  *desc[N_PAR]   = {
 static const double rppscan_values[N_PAR] = {0.001};
 static const double rppscan01_values[N_PAR] = {0.01};
   
-#include "decl_mgga.h"
 #include "maple2c/mgga_exc/mgga_c_rppscan.c"
 #include "work_mgga.c"
 
@@ -42,10 +41,10 @@ const xc_func_info_type xc_func_info_mgga_c_rppscan = {
   XC_CORRELATION,
   "r++SCAN: rSCAN with uniform density limit and coordinate scaling behavior",
   XC_FAMILY_MGGA,
-  {&xc_ref_Furness2021, NULL, NULL, NULL, NULL},
+  {&xc_ref_Furness2022_034109, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-15,
   {N_PAR, names, desc, rppscan_values, set_ext_params_cpy},
   mgga_c_rppscan_init, NULL,
-  NULL, NULL, work_mgga,
+  NULL, NULL, &work_mgga,
 };
